#' PE films supplied by Etola Oy
#'
#' Dataset containing the wavelengths at a 1 nm interval and
#' tabulated values spectral transmittance for different filters supplied by
#' Etola Oy (Finland).
#'
#' The variables are as follows:
#'
#' \itemize{
#'   \item w.length (nm)
#'   \item Tfr (fraction)
#' }
#'
#' @docType data
#' @keywords datasets
#' @format A vector of character strings.
#'
#' @note Idependent measurement of a single sample, not a specification.
#'
#' @examples
#' etola_filters
#'
"etola_filters"
